==> haskell-primitive-addr-0.1.0.2-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-2fFmHhyi7cj2OcwSKJsRkr
key:                  primitive-addr-0.1.0.2-2fFmHhyi7cj2OcwSKJsRkr
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  56c37e89bb0d1f41b8e7780744ab3e38
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-2fFmHhyi7cj2OcwSKJsRkr
depends:
    base-4.17.2.1 primitive-0.9.0.0-BHqivtPzLOB6VfmzYm3KVP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-addr-0.1.0.2-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-3wufpIVAEpRIfKsqk297yl
key:                  primitive-addr-0.1.0.2-3wufpIVAEpRIfKsqk297yl
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  9b4e4eead300bbdce698f86aca382f8f
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-3wufpIVAEpRIfKsqk297yl
depends:
    base-4.17.2.1 primitive-0.9.0.0-7BIYbmztPZn4k2gFg33YHr

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
